@@ -2,7 +2,8 @@
 PyMove
 ======
 
-Provides  processing and visualization of trajectories and other spatial-temporal data
+Provides  processing and visualization of trajectories and other
+spatial-temporal data
 
 """
 
