@@ -40,7 +40,8 @@ def elbow_method(move_data, k_initial=1, max_clusters=15, k_iteration=1):
 
     """
 
-    message = 'Executing Elbow Method to:\n...K of %s to %s from k_iteration:%s\n' % (k_initial, max_clusters, k_iteration)
+    message = 'Executing Elbow Method to:\n...K of %s to %s from k_iteration:%s\n'
+    message = message % (k_initial, max_clusters, k_iteration)
     print(message, flush=True)
     inertia_dic = {}
     for k in progress_bar(range(k_initial, max_clusters + 1, k_iteration)):
@@ -80,7 +81,8 @@ def gap_statistic(
 
     """
 
-    message = 'Executing Gap Statistic to:\n...K of %s to %s from k_iteration:%s\n' % (k_initial, max_clusters, k_iteration)
+    message = 'Executing Gap Statistic to:\n...K of %s to %s from k_iteration:%s\n'
+    message = message % (k_initial, max_clusters, k_iteration)
     print(message, flush=True)
     gaps = {}
     for k in progress_bar(range(k_initial, max_clusters + 1, k_iteration)):
@@ -97,9 +99,9 @@ def gap_statistic(
             ref_disps[i] = km.inertia_
         # Fit cluster to original data and create dispersion
         km = KMeans(k).fit(move_data)
-        origDisp = km.inertia_
+        orig_disp = km.inertia_
         # Calculate gap statistic
-        gap = np.log(np.mean(ref_disps)) - np.log(origDisp)
+        gap = np.log(np.mean(ref_disps)) - np.log(orig_disp)
         # Assign this loop's gap statistic to gaps
         gaps[k] = gap
 
