@@ -8,21 +8,26 @@ from pymove.utils import constants
 def lat_meters(lat):
     """
     Transform latitude degree to meters.
+
     Parameters
     ----------
     lat : float
         This represent latitude value.
+
     Returns
     -------
-    meters : float
+    float
         Represents the corresponding latitude value in meters.
+
     Examples
     --------
-    Example: Latitude in Fortaleza: -3.8162973555
+    Latitude in Fortaleza: -3.8162973555
     >>> from pymove.utils.conversions import lat_meters
     >>> lat_meters(-3.8162973555)
         110826.6722516857
+
     """
+
     rlat = float(lat) * math.pi / 180
     # meter per degree Latitude
     meters_lat = (
@@ -34,7 +39,7 @@ def lat_meters(lat):
     return meters
 
 
-def list_to_str(input_list, delimiter=","):
+def list_to_str(input_list, delimiter=','):
     """
     Concatenates list elements, joining them by the separator specified by the
     parameter "delimiter".
@@ -49,9 +54,12 @@ def list_to_str(input_list, delimiter=","):
 
     Returns
     -------
-    String
-        Returns a string, resulting from concatenation of list's elements, separeted by the delimiter.
+    str
+        Returns a string, resulting from concatenation of list's elements,
+        separeted by the delimiter.
+
     """
+
     return delimiter.join(
         [x if isinstance(x, str) else repr(x) for x in input_list]
     )
@@ -68,8 +76,9 @@ def list_to_csv_str(input_list):
 
     Returns
     -------
-    String
-        Returns a string, resulting from concatenation of list's elements, separeted by ",".
+    str
+        Returns a string, resulting from concatenation of list's elements,
+        separeted by ",".
 
     Example
     -------
@@ -77,7 +86,9 @@ def list_to_csv_str(input_list):
     >>> a = [1, 2, 3, 4, 5]
     >>> conversions.list_to_csv_str(a)
     '1 1:2 2:3 3:4 4:5'
+
     """
+
     return list_to_str(input_list)
 
 
@@ -92,8 +103,9 @@ def list_to_svm_line(original_list):
 
     Returns
     -------
-    String
-        Returns a string, resulting from concatenation of list elements in consecutive element pairs, separeted by " ".
+    str
+        Returns a string, resulting from concatenation of list elements
+        in consecutive element pairs, separeted by " ".
 
     Example
     -------
@@ -101,11 +113,13 @@ def list_to_svm_line(original_list):
     >>> a = [1, 2, 3, 4, 5]
     >>> conversions.list_to_svm_line(a)
     '1 1:2 2:3 3:4 4:5'
+
     """
+
     list_size = len(original_list)
-    svm_line = "%s " % original_list[0]
+    svm_line = '%s ' % original_list[0]
     for i in range(1, list_size):
-        svm_line += "{}:{} ".format(i, original_list[i])
+        svm_line += '%s:%s ' % (i, original_list[i])
     return svm_line.rstrip()
 
 
@@ -132,7 +146,9 @@ def lon_to_x_spherical(lon):
     References
     ----------
     https://epsg.io/transform
+
     """
+
     return 6378137 * np.radians(lon)
 
 
@@ -159,7 +175,9 @@ def lat_to_y_spherical(lat):
     References
     ----------
     https://epsg.io/transform
+
     """
+
     return 6378137 * np.log(np.tan(np.pi / 4 + np.radians(lat) / 2.0))
 
 
@@ -186,7 +204,9 @@ def x_to_lon_spherical(x):
     References
     ----------
     https://epsg.io/transform
+
     """
+
     return np.degrees(x / 6378137.0)
 
 
@@ -213,11 +233,18 @@ def y_to_lat_spherical(y):
     References
     ----------
     https://epsg.io/transform
+
     """
+
     return np.degrees(np.arctan(np.sinh(y / 6378137.0)))
 
 
-def ms_to_kmh(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, inplace=True):
+def ms_to_kmh(
+    move_data,
+    label_speed=constants.SPEED_TO_PREV,
+    new_label=None,
+    inplace=True,
+):
     """
     Convert values, in ms, in label_speed column to kmh.
 
@@ -233,20 +260,22 @@ def ms_to_kmh(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, in
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
         if label_speed not in move_data:
             move_data.generate_dist_time_speed_features()
-        move_data[label_speed] = move_data[label_speed].transform(
+        move_data[label_speed] = move_data[label_speed].apply(
             lambda row: row * 3.6
         )
         if new_label is not None:
@@ -257,7 +286,12 @@ def ms_to_kmh(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, in
         raise e
 
 
-def kmh_to_ms(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, inplace=True):
+def kmh_to_ms(
+    move_data,
+    label_speed=constants.SPEED_TO_PREV,
+    new_label=None,
+    inplace=True,
+):
     """
     Convert values, in kmh, in label_speed column to ms.
 
@@ -273,21 +307,23 @@ def kmh_to_ms(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, in
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
         if label_speed not in move_data:
             move_data.generate_dist_time_speed_features()
             ms_to_kmh(move_data, label_speed, new_label)
-        move_data[label_speed] = move_data[label_speed].transform(
+        move_data[label_speed] = move_data[label_speed].apply(
             lambda row: row / 3.6
         )
         if new_label is not None:
@@ -299,7 +335,10 @@ def kmh_to_ms(move_data, label_speed=constants.SPEED_TO_PREV, new_label=None, in
 
 
 def meters_to_kilometers(
-    move_data, label_distance=constants.DIST_TO_PREV, new_label=None, inplace=True
+    move_data,
+    label_distance=constants.DIST_TO_PREV,
+    new_label=None,
+    inplace=True,
 ):
     """
     Convert values, in meters, in label_distance column to kilometers.
@@ -316,20 +355,22 @@ def meters_to_kilometers(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
         if label_distance not in move_data:
             move_data.generate_dist_time_speed_features()
-        move_data[label_distance] = move_data[label_distance].transform(
+        move_data[label_distance] = move_data[label_distance].apply(
             lambda row: row / 1000
         )
         if new_label is not None:
@@ -341,7 +382,10 @@ def meters_to_kilometers(
 
 
 def kilometers_to_meters(
-    move_data, label_distance=constants.DIST_TO_PREV, new_label=None, inplace=True
+    move_data,
+    label_distance=constants.DIST_TO_PREV,
+    new_label=None,
+    inplace=True,
 ):
     """
     Convert values, in kilometers, in label_distance column to meters.
@@ -358,21 +402,23 @@ def kilometers_to_meters(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
         if label_distance not in move_data:
             move_data.generate_dist_time_speed_features()
             meters_to_kilometers(move_data, label_distance, new_label)
-        move_data[label_distance] = move_data[label_distance].transform(
+        move_data[label_distance] = move_data[label_distance].apply(
             lambda row: row * 1000
         )
         if new_label is not None:
@@ -401,20 +447,22 @@ def seconds_to_minutes(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
         if label_time not in move_data:
             move_data.generate_dist_time_speed_features()
-        move_data[label_time] = move_data[label_time].transform(
+        move_data[label_time] = move_data[label_time].apply(
             lambda row: row / 60.0
         )
         if new_label is not None:
@@ -443,14 +491,16 @@ def minute_to_seconds(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
@@ -486,14 +536,16 @@ def minute_to_hours(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
@@ -529,14 +581,16 @@ def hours_to_minute(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
@@ -572,14 +626,16 @@ def seconds_to_hours(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
@@ -614,14 +670,16 @@ def hours_to_seconds(
         Represents a new column that will contain the conversion result.
 
     inplace: Boolean, optional, default True.
-        Wether the operation will be done in the original dataframe
+        Whether the operation will be done in the original dataframe
 
     Returns
     -------
-        move_data: dataframe or None
-            A new dataframe with the converted feature if operation
-            not done inplace
+    dataframe or None
+        A new dataframe with the converted feature if operation
+        not done inplace
+
     """
+
     try:
         if not inplace:
             move_data = move_data[:]
